@@ -1,4 +1,5 @@
 use crate::app::{App, Mode};
+use crate::widgets::CmdLine;
 use tui::backend::Backend;
 use tui::layout::{Constraint, Direction, Layout};
 use tui::Frame;
@@ -10,13 +11,13 @@ pub fn draw<B: Backend>(f: &mut Frame<B>, app: &mut App) {
         .margin(2)
         .constraints([Constraint::Length(3), Constraint::Min(1)].as_ref())
         .split(f.size());
-    f.render_widget(app.cmd_line.clone(), chunks[0]);
-    f.render_widget(app.main_widget.clone(), chunks[1]);
+    f.render_stateful_widget(CmdLine, chunks[0], &mut app.state);
+    f.render_stateful_widget(app.main_widget.clone(), chunks[1], &mut app.state);
 
     match app.state.mode {
         Mode::Normal => {}
         Mode::Command => f.set_cursor(
-            chunks[0].x + app.cmd_line.message.width() as u16 + 1,
+            chunks[0].x + app.state.message.width() as u16 + 1,
             chunks[0].y + 1,
         ),
         Mode::Insert => {
